==========
``tables``
==========

.. automodule:: tt.tables


``tables.truth_table`` module
-----------------------------

.. automodule:: tt.tables.truth_table
    :members:
    :exclude-members: __weakref__
